==> nextcloud-31.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/sr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Систем додао системску ознаку %1$s",
    "Added system tag {systemtag}" : "Додата системска ознака {systemtag}",
    "Added system tag %1$s" : "Додата системска ознака %1$s",
    "%1$s added system tag %2$s" : "%1$s је додао системску ознаку %2$s",
    "{actor} added system tag {systemtag}" : "{actor} је додао системску ознаку {systemtag}",
    "System tag %1$s removed by the system" : "Систем уклонио системску ознаку %1$s",
    "Removed system tag {systemtag}" : "Уклоњена системска ознака {systemtag}",
    "Removed system tag %1$s" : "Уклоњена системска ознака %1$s",
    "%1$s removed system tag %2$s" : "%1$sуклонио системску ознаку %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} уклонио системску ознаку {systemtag}",
    "You created system tag %1$s" : "Направили сте системску ознаку %1$s",
    "You created system tag {systemtag}" : "Направили сте системску ознаку {systemtag}",
    "%1$s created system tag %2$s" : "%1$s направио системску ознаку %2$s",
    "{actor} created system tag {systemtag}" : "{actor} направио системску ознаку {systemtag}",
    "You deleted system tag %1$s" : "Избрисали сте системску ознаку %1$s",
    "You deleted system tag {systemtag}" : "Избрисали сте системску ознаку {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s обрисао системску ознаку %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} обрисао системску ознаку {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ажурирали сте системску ознаку %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ажурирали сте системску ознаку {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ажурирао системску ознаку %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ажурирао системску ознаку {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Систем је додао системску ознаку %2$s на %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Систем је додао системску ознаку {systemtag} на {file}",
    "You added system tag %2$s to %1$s" : "Додали сте системску ознаку %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Додали сте системску ознаку {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додао системску ознаку %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додао системску ознаку {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Систем је уклонио системску ознаку %2$s са фајла %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Систем је уклонио системску ознаку {systemtag} са фајла {file}",
    "You removed system tag %2$s from %1$s" : "Уклонили сте системску ознаку %2$s са %1$s",
    "You removed system tag {systemtag} from {file}" : "Уклонили сте системску ознаку {systemtag} са {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s уклонио системску ознаку %3$s са %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} уклонио системску ознаку {systemtag} са {file}",
    "%s (restricted)" : "%s (ограничена)",
    "%s (invisible)" : "%s (невидљива)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системске ознаке</strong> за фајл су измењене",
    "Files" : "Фајлови",
    "Tags" : "Ознаке",
    "All tagged %s …" : "Све означено %s …",
    "tagged %s" : "означено %s",
    "Collaborative tags" : "Тимске ознаке",
    "Collaborative tagging functionality which shares tags among people." : "Могућност заједничког означавања којим се деле ознаке међу људима.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функција заједничког означавања којом се ознаке деле међу људима. Одлично за тимове.\n\t(ако сте пружалац услуге са инсталацијом на више различитих локација, саветује се да искључите ову апликацију пошто се ознаке свакако деле.)",
    "Public" : "Јавна",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидљива",
    "Created tag" : "Креирана ознака",
    "Failed to create tag" : "Ознака није могла да се креира",
    "Updated tag" : "Ажурирана ознака",
    "Failed to update tag" : "Није успело ажурирање ознаке",
    "Deleted tag" : "Обрисана ознака",
    "Failed to delete tag" : "Ознака није могла да се обрише",
    "Create or edit tags" : "Креирај или уреди ознаке",
    "Search for a tag to edit" : "Претрага ознаке за уређивање",
    "Collaborative tags …" : "Ознаке сарадње...",
    "No tags to select" : "Нема ниједне ознаке која може да се изабере",
    "Tag name" : "Назив ознаке",
    "Tag level" : "Ниво ознаке",
    "Create" : "Направи",
    "Update" : "Ажурирај",
    "Delete" : "Обриши",
    "Reset" : "Ресетуј",
    "Loading …" : "Учитавање…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} ће да се постави и {tag2} ће да се уклони из 1 фајла.","{tag1} ће да се постави и {tag2} ће да се уклони из {count} фајла.","{tag1} ће да се постави и {tag2} ће да се уклони из {count} фајлова."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} ће да се постави на 1 фајл.","{tag} ће да се постави на {count} фајла.","{tag} ће да се постави на {count} фајлова."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} ће се уклонити са 1 фајла.","{tag} ће се уклонити са {count} фајла.","{tag} ће се уклонити са {count} фајлова."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} и {lastTag} ће се поставити на 1 фајл.","{tags} и {lastTag} ће се поставити на {count} фајла.","{tags} и {lastTag} ће се поставити на {count} фајлова."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} и {lastTag} ће се уклонити са 1 фајла.","{tags} и {lastTag} ће се уклонити са {count} фајла.","{tags} и {lastTag} ће се уклонити са {count} фајлова."],
    "{displayName} (hidden)" : "{displayName} (скривено)",
    "{displayName} (restricted)" : "{displayName} (ограничено)",
    "Only admins can create new tags" : "Нове ознаке могу да креирају само админи",
    "Failed to apply tags changes" : "Није успело примењивање измена ознака",
    "File tags modification canceled" : "Отказана је измена ознака фајла",
    "Manage tags" : "Управљање ознакама",
    "Applying tags changes…" : "Примењују се измене ознака…",
    "Search or create tag" : "Претражи или креирај ознаку",
    "Search tag" : "Претражи ознаку",
    "Change tag color" : "Промени боју ознаке",
    "Create new tag" : "Креирај нову ознаку",
    "Select or create tags to apply to all selected files" : "Избор или креирање ознака које ће се применити на све изабране фајлове",
    "Select tags to apply to all selected files" : "Изаберите ознаке које ће се применити на све изабране фајлове",
    "Cancel" : "Откажи",
    "Apply changes" : "Примени измене",
    "Failed to load tags" : "Грешка при учитавању ознака",
    "Failed to load selected tags" : "Изабрана ознака није могла да се учита",
    "Failed to select tag" : "Ознака није могла да се изабере",
    "System admin disabled tag creation. You can only use existing ones." : "Админ система је искључио креирање ознака. Можете да употребљавате само постојеће ознаке.",
    "Loading collaborative tags …" : "Учитавају се ознаке сарадње…",
    "Search or create collaborative tags" : "Претражите или креирајте ознаке за сарадњу",
    "No tags to select, type to create a new tag" : "Није изабрана ниједна ознака, куцајте да креирате нову ознаку",
    "Unable to update setting" : "Није успело ажурирање подешавања",
    "System tag creation is now restricted to administrators" : "Креирање системске ознаке је сада ограничено само на администраторе",
    "System tag creation is now allowed for everybody" : "Креирање системске ознаке је сада дозвољено свима",
    "System tag management" : "Системско управљање ознакама",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Ако се укључи, само администратори могу да креирају и уређују ознаке. Налози и даље могу да их додељују или уклањају са фајлова.",
    "Restrict tag creation and editing to administrators" : "Ограничи креирање и уређивање ознака само администраторима",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Заједниче ознаке су доступне свим корисницима. Заштићене ознаке су доступне свим корисницима, али их они не могу додељивати. Невидљиве ознаке су за интерну употребу, пошто их корисници не могу ни видети ни додељивати.",
    "Assigned collaborative tags" : "Додељене ознаке сарадње",
    "Open in Files" : "Отвори у Фајловима",
    "List of tags and their associated files and folders." : "Листа ознака и њима придружени фајлови и директоријуми.",
    "No tags found" : "Нису нађене ознаке",
    "Tags you have created will show up here." : "Овде ће се појавити ознаке које сте креирали.",
    "Failed to load tag" : "Није успело учитавање ознаке",
    "Failed to load last used tags" : "Последње коришћена ознака није могла да се учита",
    "Missing \"Content-Location\" header" : "Недостаје Content-Location” заглавље",
    "A tag with the same name already exists" : "Већ постоји ознака са истим именом",
    "Failed to load tags for file" : "Није успело учитавање ознака за фајл",
    "Failed to set tag for file" : "Није успело постављање ознака за фајл",
    "Failed to delete tag for file" : "Није успело брисање ознака за фајл",
    "This file has the tag {tag}" : "Овај фајл има ознаку {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Овај фајл има ознаке {firstTags} и {lastTag}"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/sr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Систем додао системску ознаку %1$s",
    "Added system tag {systemtag}" : "Додата системска ознака {systemtag}",
    "Added system tag %1$s" : "Додата системска ознака %1$s",
    "%1$s added system tag %2$s" : "%1$s је додао системску ознаку %2$s",
    "{actor} added system tag {systemtag}" : "{actor} је додао системску ознаку {systemtag}",
    "System tag %1$s removed by the system" : "Систем уклонио системску ознаку %1$s",
    "Removed system tag {systemtag}" : "Уклоњена системска ознака {systemtag}",
    "Removed system tag %1$s" : "Уклоњена системска ознака %1$s",
    "%1$s removed system tag %2$s" : "%1$sуклонио системску ознаку %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} уклонио системску ознаку {systemtag}",
    "You created system tag %1$s" : "Направили сте системску ознаку %1$s",
    "You created system tag {systemtag}" : "Направили сте системску ознаку {systemtag}",
    "%1$s created system tag %2$s" : "%1$s направио системску ознаку %2$s",
    "{actor} created system tag {systemtag}" : "{actor} направио системску ознаку {systemtag}",
    "You deleted system tag %1$s" : "Избрисали сте системску ознаку %1$s",
    "You deleted system tag {systemtag}" : "Избрисали сте системску ознаку {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s обрисао системску ознаку %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} обрисао системску ознаку {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ажурирали сте системску ознаку %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ажурирали сте системску ознаку {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ажурирао системску ознаку %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ажурирао системску ознаку {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Систем је додао системску ознаку %2$s на %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Систем је додао системску ознаку {systemtag} на {file}",
    "You added system tag %2$s to %1$s" : "Додали сте системску ознаку %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Додали сте системску ознаку {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додао системску ознаку %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додао системску ознаку {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Систем је уклонио системску ознаку %2$s са фајла %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Систем је уклонио системску ознаку {systemtag} са фајла {file}",
    "You removed system tag %2$s from %1$s" : "Уклонили сте системску ознаку %2$s са %1$s",
    "You removed system tag {systemtag} from {file}" : "Уклонили сте системску ознаку {systemtag} са {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s уклонио системску ознаку %3$s са %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} уклонио системску ознаку {systemtag} са {file}",
    "%s (restricted)" : "%s (ограничена)",
    "%s (invisible)" : "%s (невидљива)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системске ознаке</strong> за фајл су измењене",
    "Files" : "Фајлови",
    "Tags" : "Ознаке",
    "All tagged %s …" : "Све означено %s …",
    "tagged %s" : "означено %s",
    "Collaborative tags" : "Тимске ознаке",
    "Collaborative tagging functionality which shares tags among people." : "Могућност заједничког означавања којим се деле ознаке међу људима.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функција заједничког означавања којом се ознаке деле међу људима. Одлично за тимове.\n\t(ако сте пружалац услуге са инсталацијом на више различитих локација, саветује се да искључите ову апликацију пошто се ознаке свакако деле.)",
    "Public" : "Јавна",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидљива",
    "Created tag" : "Креирана ознака",
    "Failed to create tag" : "Ознака није могла да се креира",
    "Updated tag" : "Ажурирана ознака",
    "Failed to update tag" : "Није успело ажурирање ознаке",
    "Deleted tag" : "Обрисана ознака",
    "Failed to delete tag" : "Ознака није могла да се обрише",
    "Create or edit tags" : "Креирај или уреди ознаке",
    "Search for a tag to edit" : "Претрага ознаке за уређивање",
    "Collaborative tags …" : "Ознаке сарадње …",
    "No tags to select" : "Нема ниједне ознаке која може да се изабере",
    "Tag name" : "Назив ознаке",
    "Tag level" : "Ниво ознаке",
    "Create" : "Направи",
    "Update" : "Ажурирај",
    "Delete" : "Обриши",
    "Reset" : "Ресетуј",
    "Loading …" : "Учитава се…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} ће да се постави и {tag2} ће да се уклони из 1 фајла.","{tag1} ће да се постави и {tag2} ће да се уклони из {count} фајла.","{tag1} ће да се постави и {tag2} ће да се уклони из {count} фајлова."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} ће да се постави на 1 фајл.","{tag} ће да се постави на {count} фајла.","{tag} ће да се постави на {count} фајлова."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} ће се уклонити са 1 фајла.","{tag} ће се уклонити са {count} фајла.","{tag} ће се уклонити са {count} фајлова."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} и {lastTag} ће се поставити на 1 фајл.","{tags} и {lastTag} ће се поставити на {count} фајла.","{tags} и {lastTag} ће се поставити на {count} фајлова."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} и {lastTag} ће се уклонити са 1 фајла.","{tags} и {lastTag} ће се уклонити са {count} фајла.","{tags} и {lastTag} ће се уклонити са {count} фајлова."],
    "{displayName} (hidden)" : "{displayName} (скривено)",
    "{displayName} (restricted)" : "{displayName} (ограничено)",
    "Only admins can create new tags" : "Нове ознаке могу да креирају само админи",
    "Failed to apply tags changes" : "Није успело примењивање измена ознака",
    "Manage tags" : "Управљање ознакама",
    "Applying tags changes…" : "Примењују се измене ознака…",
    "Search or create tag" : "Претражи или креирај ознаку",
    "Search tag" : "Претражи ознаку",
    "Change tag color" : "Промени боју ознаке",
    "Create new tag" : "Креирај нову ознаку",
    "Choose tags for the selected files" : "Изаберите ознаке за изабране фајлове",
    "Cancel" : "Откажи",
    "Apply" : "Примени",
    "Failed to load selected tags" : "Изабрана ознака није могла да се учита",
    "Failed to load tags" : "Грешка при учитавању ознака",
    "Failed to select tag" : "Ознака није могла да се изабере",
    "System admin disabled tag creation. You can only use existing ones." : "Админ система је искључио креирање ознака. Можете да употребљавате само постојеће ознаке.",
    "Loading collaborative tags …" : "Учитавају се ознаке сарадње …",
    "Search or create collaborative tags" : "Претражите или креирајте ознаке за сарадњу",
    "No tags to select, type to create a new tag" : "Није изабрана ниједна ознака, куцајте да креирате нову ознаку",
    "Unable to update setting" : "Није успело ажурирање подешавања",
    "System tag creation is now restricted to administrators" : "Креирање системске ознаке је сада ограничено само на администраторе",
    "System tag creation is now allowed for everybody" : "Креирање системске ознаке је сада дозвољено свима",
    "System tag management" : "Системско управљање ознакама",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Ако се укључи, само администратори могу да креирају и уређују ознаке. Налози и даље могу да их додељују или уклањају са фајлова.",
    "Restrict tag creation and editing to administrators" : "Ограничи креирање и уређивање ознака само администраторима",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Заједниче ознаке су доступне свим корисницима. Заштићене ознаке су доступне свим корисницима, али их они не могу додељивати. Невидљиве ознаке су за интерну употребу, пошто их корисници не могу ни видети ни додељивати.",
    "Add tags" : "Додај ознаке",
    "Assigned collaborative tags" : "Додељене ознаке сарадње",
    "Open in Files" : "Отвори у Фајловима",
    "List of tags and their associated files and folders." : "Листа ознака и њима придружени фајлови и директоријуми.",
    "No tags found" : "Нису нађене ознаке",
    "Tags you have created will show up here." : "Овде ће се појавити ознаке које сте креирали.",
    "Failed to load tag" : "Није успело учитавање ознаке",
    "Failed to load last used tags" : "Последње коришћена ознака није могла да се учита",
    "Missing \"Content-Location\" header" : "Недостаје Content-Location” заглавље",
    "A tag with the same name already exists" : "Већ постоји ознака са истим именом",
    "Failed to load tags for file" : "Није успело учитавање ознака за фајл",
    "Failed to set tag for file" : "Није успело постављање ознака за фајл",
    "Failed to delete tag for file" : "Није успело брисање ознака за фајл",
    "Collaborative tags …" : "Ознаке сарадње...",
    "Loading …" : "Учитавање…",
    "File tags modification canceled" : "Отказана је измена ознака фајла",
    "Select or create tags to apply to all selected files" : "Избор или креирање ознака које ће се применити на све изабране фајлове",
    "Select tags to apply to all selected files" : "Изаберите ознаке које ће се применити на све изабране фајлове",
    "Apply changes" : "Примени измене",
    "Loading collaborative tags …" : "Учитавају се ознаке сарадње…"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
